@@ -258,7 +258,7 @@ class Kraken_html:
 
     def get_record_template(self, page, language = 'en'):
         # Get file Name. 
-        filename = 'content_template/' + page + '_' + language + '.json'
+        filename = 'kraken_html/content_template/' + page + '_' + language + '.json'
 
         # Load file
         f = open(filename, "r")
